pub fn post<URL, BODY, F>(url: URL, body: BODY, f: F)Expand description
Most simple way to make a http post request, the gzip will be enabled if data greater than 1 KB.
fn test() {
wsd::http::post("https://docs.rs/", "{id: 100}", |data| {
println!("status = {}, data = {}", data.status(), data.text());
});
}